@@ -36,6 +36,7 @@ from mysql_mimic.types import (
     ComStmtExecuteFlags,
     peek,
     ServerStatus,
+    read_str_rest,
 )
 
 
@@ -106,6 +107,12 @@ class ComStmtClose:
     stmt_id: int
 
 
+@dataclass
+class ComFieldList:
+    table: str
+    wildcard: str
+
+
 def make_ok(
     capabilities: Capabilities,
     status_flags: ServerStatus,
@@ -466,6 +473,18 @@ def parse_com_stmt_close(data: bytes) -> ComStmtClose:
     return ComStmtClose(stmt_id=read_uint_4(r))
 
 
+def parse_com_init_db(client_charset: CharacterSet, data: bytes) -> str:
+    return client_charset.decode(data)
+
+
+def parse_com_field_list(client_charset: CharacterSet, data: bytes) -> ComFieldList:
+    r = io.BytesIO(data)
+    return ComFieldList(
+        table=client_charset.decode(read_str_null(r)),
+        wildcard=client_charset.decode(read_str_rest(r)),
+    )
+
+
 def _read_cursor_flags(reader: io.BytesIO) -> Tuple[bool, bool]:
     flags = ComStmtExecuteFlags(read_uint_1(reader))
     param_count_available = ComStmtExecuteFlags.PARAMETER_COUNT_AVAILABLE in flags
